﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;

namespace HeuristicLab.Visualization.Primitives {
  public class TextPrimitive : RectangularPrimitiveBase {
    public Font Font { get; set; }
    public string Text { get; set; }

    public TextPrimitive(IChart chart, PointD lowerLeft, PointD upperRight) : base(chart, lowerLeft, upperRight) { }

    public TextPrimitive(IChart chart, PointD lowerLeft, PointD upperRight, Pen pen, Brush brush) : base(chart, lowerLeft, upperRight, pen, brush) { }

    public TextPrimitive(IChart chart, double x1, double y1, double x2, double y2) : this(chart, new PointD(x1, y1), new PointD(x2, y2)) { }

    public override void Draw(Graphics graphics) {
      base.Draw(graphics);
      // draw the text in the center of the bounding rectangle4
      var p = Chart.TransformWorldToPixel(new PointD(LowerLeft.X, LowerLeft.Y));
      var s = Chart.TransformWorldToPixel(Size);
      var stringSize = graphics.MeasureString(Text, Font);
      var fontSize = Font.Size * s.Width / stringSize.Width;
      if (fontSize > 12) fontSize = 12; // limit maximum font size so that nodes look nicer
      Font = new Font(Font.FontFamily, fontSize, GraphicsUnit.Pixel);
      stringSize = graphics.MeasureString(Text, Font);
      graphics.DrawString(Text, Font, new SolidBrush(Pen.Color), p.X + (s.Width - stringSize.Width) / 2f, p.Y - (s.Height + stringSize.Height) / 2f);
    }
  }
}
